@@ -1,13 +1,11 @@
 # pylint:disable=missing-module-docstring
-from typing import Callable
-from typing import Iterable
+from typing import Callable, Iterable
 
 from ray.rllib.evaluation.worker_set import WorkerSet
 from ray.rllib.execution.metric_ops import StandardMetricsReporting
 from ray.rllib.execution.rollout_ops import ParallelRollouts
 from ray.rllib.execution.train_ops import TrainOneStep
-from ray.rllib.utils.typing import ResultDict
-from ray.rllib.utils.typing import TrainerConfigDict
+from ray.rllib.utils.typing import ResultDict, TrainerConfigDict
 
 from raylab.execution import LearningStarts
 from raylab.options import option
