@@ -3,15 +3,12 @@ import torch
 from ray.rllib.utils import override
 from torch.nn.utils import clip_grad_norm_
 
-from raylab.options import configure
-from raylab.options import option
+from raylab.options import configure, option
 from raylab.policy import TorchPolicy
 from raylab.policy.action_dist import WrapDeterministicPolicy
-from raylab.policy.losses import DeterministicPolicyGradient
-from raylab.policy.losses import FittedQLearning
+from raylab.policy.losses import DeterministicPolicyGradient, FittedQLearning
 from raylab.policy.modules.critic import HardValue
-from raylab.policy.off_policy import off_policy_options
-from raylab.policy.off_policy import OffPolicyMixin
+from raylab.policy.off_policy import OffPolicyMixin, off_policy_options
 from raylab.torch.nn.utils import update_polyak
 from raylab.torch.optim import build_optimizer
 from raylab.utils.types import TensorDict
