@@ -1,21 +1,15 @@
 """Loss functions for Maximum Likelihood Estimation."""
-from typing import List
-from typing import Tuple
-from typing import Union
+from typing import List, Tuple, Union
 
 import torch
 import torch.nn as nn
 from ray.rllib import SampleBatch
 from torch import Tensor
-from torch.jit import fork
-from torch.jit import wait
+from torch.jit import fork, wait
 
-from raylab.policy.modules.model import ForkedSME
-from raylab.policy.modules.model import SME
-from raylab.policy.modules.model import StochasticModel
+from raylab.policy.modules.model import SME, ForkedSME, StochasticModel
 from raylab.utils.dictionaries import get_keys
-from raylab.utils.types import StatDict
-from raylab.utils.types import TensorDict
+from raylab.utils.types import StatDict, TensorDict
 
 from .abstract import Loss
 
