@@ -1,6 +1,5 @@
 """Parameterized action-value estimators."""
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from typing import List
 
 import torch
@@ -10,7 +9,6 @@ from torch import Tensor
 
 from raylab.policy.modules.networks.mlp import StateActionMLP
 
-
 MLPSpec = StateActionMLP.spec_cls
 
 
