@@ -1,18 +1,17 @@
 """Customized modules."""
 from .action_output import ActionOutput
 from .activation import Swish
-from .dist_params import CategoricalParams
-from .dist_params import NormalParams
-from .dist_params import PolicyNormalParams
-from .dist_params import StdNormalParams
-from .fully_connected import FullyConnected
-from .fully_connected import MADE
-from .fully_connected import StateActionEncoder
+from .dist_params import (
+    CategoricalParams,
+    NormalParams,
+    PolicyNormalParams,
+    StdNormalParams,
+)
+from .fully_connected import MADE, FullyConnected, StateActionEncoder
 from .gaussian_noise import GaussianNoise
 from .lambd import Lambda
 from .leaf_parameter import LeafParameter
-from .linear import MaskedLinear
-from .linear import NormalizedLinear
+from .linear import MaskedLinear, NormalizedLinear
 from .tanh_squash import TanhSquash
 from .tril_matrix import TrilMatrix
 
